@@ -1,7 +1,7 @@
 package Email::Sender::Transport::SMTP::TLS;
 
 BEGIN {
-    $Email::Sender::Transport::SMTP::TLS::VERSION = '0.09';
+    $Email::Sender::Transport::SMTP::TLS::VERSION = '0.10';
 }
 
 # ABSTRACT: Email::Sender with L<Net::SMTP::TLS> (Eg. Gmail)
@@ -17,6 +17,7 @@ has host     => ( is => 'ro', isa => 'Str', default  => 'localhost' );
 has port     => ( is => 'ro', isa => 'Int', default  => 587 );
 has username => ( is => 'ro', isa => 'Str', required => 1 );
 has password => ( is => 'ro', isa => 'Str', required => 1 );
+has timeout  => ( is => 'ro', isa => 'Int', default  => 0 );
 has allow_partial_success => ( is => 'ro', isa => 'Bool', default => 0 );
 has helo => ( is => 'ro', isa => 'Str' );    # default to hostname_long
 
@@ -45,7 +46,8 @@ sub _smtp_client {
             Port     => $self->port,
             User     => $self->username,
             Password => $self->password,
-            $self->helo ? ( Hello => $self->helo ) : (),
+            $self->helo    ? ( Hello   => $self->helo )    : (),
+            $self->timeout ? ( Timeout => $self->timeout ) : (),
         );
     };
 
@@ -104,16 +106,20 @@ sub send_email {
         );
     }
 
-    my $message;
     eval {
         $smtp->data();
         $smtp->datasend( $email->as_string );
         $smtp->dataend;
+    };
+    $FAULT->("error at sending: $@") if $@;
+
+    my $message;
+    eval {
         $message = $smtp->message;
         $smtp->quit;
     };
 
-    # ignore $@
+    # ignore $@ from ->quit
 
     # XXX: We must report partial success (failures) if applicable.
     return $self->success( { message => $message } ) unless @failures;
@@ -169,7 +175,7 @@ Email::Sender::Transport::SMTP::TLS - Email::Sender with L<Net::SMTP::TLS> (Eg.
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
